Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank Member List

This is the complete list of members for feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank, including all inherited members.

__init__(self, "int" num_of_inputs, "int *" num_of_neurons_per_layer_array, "int" num_filtersInput, "double" minT, "double" maxT) | feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank |
feedforward_closedloop_learning::FeedforwardClosedloopLearning.__init__(self, "int" num_of_inputs, "int *" num_of_neurons_per_layer_array) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
doStep(self, *args) | feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank |
getFilterOutput(self, "int" inputIdx, "int" filterIdx) | feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank |
getLayer(self, "int" i) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
getLayers(self) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
getNFiltersPerInput(self) | feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank |
getNumInputs(self) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
getNumLayers(self) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
getOutput(self, "int" index) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
getOutputLayer(self) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
initWeights(self, *args) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
loadModel(self, "char const *" name) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
saveModel(self, "char const *" name) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
seedRandom(self, "int" s) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setActivationFunction(self, "Neuron::ActivationFunction" _activationFunction) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setBias(self, "double" _bias) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setDecay(self, "double" decay) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setLearningRate(self, "double" learningRate) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setLearningRateDiscountFactor(self, "double" _learningRateDiscountFactor) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
setMomentum(self, "double" momentum) | feedforward_closedloop_learning.FeedforwardClosedloopLearning |
thisown (defined in feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank) | feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank | static